# Bayesian multinomial logit model of health authority allocation in EU
# R command file to run WinBUGS estimation code & post-estimation R graphics
#
# Chris Adolph
# University of Washington
# faculty.washington.edu/cadolph
#
# This is the replication code to Christopher Adolph, Scott L. Greer,
# and Elize Massard da Fonseca, "Allocation of Authority in European
# Health Policy", Social Science and Medicine, 2012.
# 
# Code is only semi-documented.  Inquiries welcome.
#
# Note you must install the tile package, available from my
# webpage above, in order to make the dotplots from the paper
#
# You must also have the various helper files "sourced" in below
# in the R path
#
# Note that running this code takes a *long* time.
#
# To save time, you can skip the estimation step and use
# a pre-estimated model by setting estimate <- FALSE below.
# Alternatively, you can skip the post-estimation simulation
# and use pre-simulated results setting prediction <- FALSE.
#
# Our estimated model and simulation results are contained in
# the results folder.
#
# Finally, if you do run the estimation step, note that the
# number of MCMC iterations is set to a high value below.  You
# may want to start smaller, but be careful to check for convergence.


rm(list = ls())
library(MASS)
library(lme4)
library(arm)
library(MCMCpack)
library(nnet)
library(abind)
library(RColorBrewer)
source("mnlbugs.r")
source("remnlccspecbugs.r")
source("predict.remnlccspec.r")
library(tile)
source("ternary2.R")

estimate <- TRUE
prediction <- TRUE
infile <- "finalmodel.Rdata"

data <- read.csv("aoafinaldata.csv",header=TRUE)
attach(data)

# Process categorical covariates
pharma <- polarea=="pharma"
primac <- polarea=="primaryc"
secter <- polarea=="secterc"
pubhea <- polarea=="pubhea"
leg1 <- poltype=="L1"
leg2 <- poltype=="L2"
fina <- poltype=="F"
prov <- poltype=="P"
natpop <- as.numeric(natpop)
natpop <- natpop/1000000
avregpop <- as.numeric(avregpop)
avregpop <- avregpop/1000000

lnatpop <- log(natpop)
lavregpop <- log(avregpop)

mountainspost73 <- mountains*post73

# Create random effects labels
group <- as.numeric(ctynum)


nonzeros <- c(1,2,3,6,9,10,
              13,19,21,22,23,25,26,27,28)

zeros <- c(4,5,7,8,11,12,14,15,16,17,18,20,24)


# Identify structural zeros
possible <- matrix(1,nrow=nrow(data),ncol=3)
pgroup <- matrix(1,nrow=length(unique(group)),ncol=3)
for (i in 1:length(nunreg)) {
    if (is.na(nunreg[i])) {
        possible[i,2] <- 0
    }
}
pgroup[zeros,2] <- 0
possiblecases <- as.logical(possible[,2])


# Create categorical response for Bayesian MNL
level <- as.character(level)
Y <- matrix(0,nrow=length(level),ncol=length(unique(level)))
for (i in 1:length(level)) {
    if (level[i]=="national")
        Y[i,1] <- 1
    if (level[i]=="regional")
        Y[i,2] <- 1
    if (level[i]=="local")
        Y[i,3] <- 1
}

# Create categorical response for neural net MNL
Y0 <-  matrix(0,nrow=length(level),ncol=length(unique(level)))
for (i in 1:length(level)) {
    if (level[i]=="national")
        Y0[i,2] <- 1
    if (level[i]=="regional")
        Y0[i,3] <- 1
    if (level[i]=="local")
        Y0[i,1] <- 1
}

# Collect covariates for Bayes
X <- cbind(pharma,
           primac,
           secter,
           pubhea,
           leg1,
           leg2,
           fina,
           prov,
           post73,
           elf85,
           mountains
           )

Z <- array(NA,dim=c(nrow(X),1,2))
Z[,1,1] <- lnatpop
Z[,1,2] <- lavregpop

# Collect covariates for nnet MNL
Xns <- cbind(pharma,
             primac,
             secter,
             leg1,
             leg2,
             fina,
             post73,
             elf85,
             mountains,
             lnatpop,
             lavregpop
             )

# Create random effects labels
group <- as.numeric(ctynum)

# Estimate likelihood version of MNL
mlogit.result <- multinom(Y0~Xns,Hess=TRUE)
pe <- mlogit.result$wts   # point estimates
vc <- solve(mlogit.result$Hess)  # var-cov matrix
se <- sqrt(diag(vc))    # standard errors
ll <- -mlogit.result$value  # likelihood at maximum
summary(mlogit.result)

# Create empirical Bayes prior
peshort <- c(pe[15:26], pe[28:39])

seshort <- as.numeric(se)

pemat <- matrix(peshort,ncol=2,nrow=(1+ncol(Xns)))
gpemat <- pemat[11:12,]
pemat <- rbind(pemat[1:4,],
               c(0,0),
               pemat[5:6,],
               c(0,0),
               pemat[7,],
               pemat[8:10,]
               )

semat <- matrix(seshort,ncol=2,nrow=(1+ncol(Xns)))
gsemat <- semat[11:12,]
semat <- rbind(semat[1:4,],
               c(1,1),
               semat[5:6,],
               c(1,1),
               semat[7,],
               semat[8:10,]
               )
precmat <- 1/(100*semat)   #  Downweighted precision
gprecmat <- 1/(100*gsemat)

source("remnlccspecbugs.r")
# Estimate Bayesian MNL with random effects

if (estimate) {
model1 <- remnlccspecbugs(Y=Y,
                          X=X,
                          Z=Z,
                          group=group,
                          possible=possible,
                          pgroup=pgroup,
                          betaprior=pemat,
                          betapriorprecision=precmat,
                          gammaprior=gpemat,
                          gammapriorprecision=gprecmat,
                          meancenter=TRUE,
                          n.chains=3,
                          n.iter=1100000,
                          n.thin=1000,
                          n.burnin=100000,
                          debug=TRUE)
} else {
  load(infile)
}

# Calculate estimated correlation matrix of random effects
library(bayesm)
nsims <- length(model1$sims.list$sigma)
correlationsims <- rep(NA,nsims)
for (i in 1:nsims) {
    correlationsims[i] <- nmat(c(1,
                                 model1$sims.list$omegap[i],
                                 model1$sims.list$omegap[i],
                                 model1$sims.list$sigma[i]^2))
}
print(mean(correlationsims))
print(quantile(correlationsims,probs=c(0.025,0.975)))


sdsims <- correlationsims <- rep(NA, nsims)
for (i in 1:nsims) {
    correlationsims[i] <- cor(model1$sims.list$alpha[i,,1],model1$sims.list$alpha[i,,2])
    sdsims[i] <- sd(model1$sims.list$alpha[i,,2])
}
summary(correlationsims)
print(quantile(correlationsims,probs=c(0.025,0.975)))

summary(sdsims)
print(quantile(sdsims,probs=c(0.025,0.975)))


# Simulate results

# All countries case
pcavregpop <- avregpop[possiblecases]
pcnatpop <- natpop[possiblecases]
regionmodel <-lm(pcavregpop~pcnatpop)
newdata <- as.data.frame(natpop)
names(newdata) <- "pcnatpop"
predavregpop <- predict(regionmodel,newdata=newdata)
prednunreg <- natpop/predavregpop
sdnunregALL <- round(sd(prednunreg))

newdata <- as.data.frame(mean(natpop))
names(newdata) <- "pcnatpop"
meanavgregpopALL <- predict(regionmodel,newdata=newdata)
meannunregALL <- mean(natpop)/meanavgregpopALL

meannatpopALL <- meannunregALL*meanavgregpopALL
lownatpopALL <- meannatpopALL - 2*sdnunregALL*meanavgregpopALL
upnatpopALL <-  meannatpopALL + 2*sdnunregALL*meanavgregpopALL

lowavgregpopALL <- meannatpopALL/(meannunregALL + 2*sdnunregALL)
upavgregpopALL <- meannatpopALL/(meannunregALL - 2*sdnunregALL)


# Existing federal states case
meanavgregpop <- mean(avregpop[possiblecases])
meannunreg <- mean(nunreg[possiblecases])
lownunreg <- quantile(nunreg[possiblecases],probs=0.25)
upnunreg <- quantile(nunreg[possiblecases],probs=0.75)

meannatpop <- mean(natpop[possiblecases])
lownatpop <- quantile(natpop[possiblecases],probs=0.25)
upnatpop <- quantile(natpop[possiblecases],probs=0.75)

meanmountains <- mean(mountains[possiblecases])
lowmountains <- quantile(mountains[possiblecases],probs=0.25)
upmountains <- quantile(mountains[possiblecases],probs=0.75)


# Two-tier states case
mediannatpopLOC <- median(natpop[!possiblecases])
lownatpopLOC <- quantile(natpop[!possiblecases],probs=0.25)
upnatpopLOC <- quantile(natpop[!possiblecases],probs=0.75)

meanmountainsLOC <- mean(mountains[!possiblecases])
lowmountainsLOC <- quantile(mountains[!possiblecases],probs=0.25)
upmountainsLOC <- quantile(mountains[!possiblecases],probs=0.75)



mean(natpop[possiblecases]/nunreg[possiblecases])

scenarios <- c("Pharmaceuticals",
  "Primary Care",
  "Secondary/Tertiary",
  "Public Health",
  "Framework",
  "Implementation",
  "Finance",
  "Provision"
  )

scenariosa <- c("Public Health",
                "Secondary/Tertiary",
                "Primary Care", 
                "Pharmaceuticals"
  )

scenariosb <- c(
                "Provision",
                "Implementation",
                "Finance",
                "Framework"
  )

# Create counterfactual scenarios:  3 tier countries 
xbase0 <- c(mean(pharma),mean(primac),mean(secter),
            mean(pubhea),mean(leg1),mean(leg2),
            mean(fina),mean(prov),
            mean(post73[possiblecases]),mean(elf85[possiblecases]))
xbase <- c(0,0,0,0,  0,0,0,0, mean(post73[possiblecases]), mean(elf85[possiblecases]), meanmountains )
zbase <- c(rep(log(meannatpop),8),
           rep(log(meanavgregpop),8)
           )

xscen <- rbind(xbase,xbase,xbase,xbase,xbase,
               xbase,xbase,xbase)
zscen <- array(zbase,dim=c(8,1,2))

xscen[1,4] <- 1;   xscen[1,5:8] <- xbase0[5:8];
xscen[2,3] <- 1;   xscen[2,5:8] <- xbase0[5:8];
xscen[3,2] <- 1;   xscen[3,5:8] <- xbase0[5:8];
xscen[4,1] <- 1;   xscen[4,5:8] <- xbase0[5:8];
xscen[5,8] <- 1;   xscen[5,1:4] <- xbase0[1:4];
xscen[6,6] <- 1;   xscen[6,1:4] <- xbase0[1:4];
xscen[7,7] <- 1;   xscen[7,1:4] <- xbase0[1:4];
xscen[8,5] <- 1;   xscen[8,1:4] <- xbase0[1:4];


source("predict.remnlccspec.r")
if (prediction) {
  ctrfct0a <- predict.remnlccspec(model1,
                                  newxdata = xscen[1:4,],
                                  newzdata = zscen[1:4,,,drop=FALSE],
                                  ranefs = "drawn",
                                  level = 0.95,
                                  savememory = 20,
                                  sims = 1000,
                                  selected = nonzeros
                                  )
  save(ctrfct0a, file="ctrfct0a.Rdata")
} else {
  load("ctrfct0a.Rdata")
}

if (prediction) {
  ctrfct0b <- predict.remnlccspec(model1,
                                  newxdata = xscen[5:8,],
                                  newzdata = zscen[5:8,,,drop=FALSE],
                                  ranefs = "drawn",
                                  level = 0.95,
                                  savememory = 20,
                                  sims = 1000,
                                  selected = nonzeros
                                  )
  save(ctrfct0b, file="ctrfct0b.Rdata")
} else {
  load("ctrfct0b.Rdata")
}

# Create counterfactual scenarios: ALL countries
xbase0ALL <- c(mean(pharma),mean(primac),mean(secter),
            mean(pubhea),mean(leg1),mean(leg2),
            mean(fina),mean(prov),
            mean(post73),mean(elf85))
xbaseALL <- c(0,0,0,0,  0,0,0,0, mean(post73),mean(elf85), meanmountains )
zbaseALL <- c(rep(log(meannatpopALL),8),
           rep(log(meanavgregpopALL),8)
           )

xscenALL <- rbind(xbaseALL,xbaseALL,xbaseALL,xbaseALL,xbaseALL,
               xbaseALL,xbaseALL,xbaseALL)
zscenALL <- array(zbaseALL,dim=c(8,1,2))

xscenALL[1,1] <- 1;   xscenALL[1,5:8] <- xbase0ALL[5:8];
xscenALL[2,2] <- 1;   xscenALL[2,5:8] <- xbase0ALL[5:8];
xscenALL[3,3] <- 1;   xscenALL[3,5:8] <- xbase0ALL[5:8];
xscenALL[4,4] <- 1;   xscenALL[4,5:8] <- xbase0ALL[5:8];
xscenALL[5,5] <- 1;   xscenALL[5,1:4] <- xbase0ALL[1:4];
xscenALL[6,6] <- 1;   xscenALL[6,1:4] <- xbase0ALL[1:4];
xscenALL[7,7] <- 1;   xscenALL[7,1:4] <- xbase0ALL[1:4];
xscenALL[8,8] <- 1;   xscenALL[8,1:4] <- xbase0ALL[1:4];

if (prediction) {
  ctrfct0aALL <- predict.remnlccspec(model1,
                                     newxdata = xscenALL[1:4,],
                                     newzdata = zscenALL[1:4,,,drop=FALSE],
                                     ranefs = "drawn",
                                     level = 0.95,
                                     savememory = 20,
                                     sims = 1000
                                     )
  save(ctrfct0aALL,file="ctrfct0aALL.Rdata")
} else {
  load("ctrfct0aALL.Rdata")
}

if (prediction) {
  ctrfct0bALL <- predict.remnlccspec(model1,
                                     newxdata = xscenALL[5:8,],
                                     newzdata = zscenALL[5:8,,,drop=FALSE],
                                     ranefs = "drawn",
                                     level = 0.95,
                                     savememory = 20,
                                     sims = 1000
                                     )
save(ctrfct0bALL,file="ctrfct0bALL.Rdata")
} else {
  load("ctrfct0bALL.Rdata")
}



# Create counterfactual scenarios:  2 tier countries 
xbase0LOC <- c(mean(pharma),mean(primac),mean(secter),
            mean(pubhea),mean(leg1),mean(leg2),
            mean(fina),mean(prov),
            mean(post73[!possiblecases]),mean(elf85[!possiblecases]))
xbaseLOC <- c(0,0,0,0,  0,0,0,0, mean(post73[!possiblecases]),mean(elf85[!possiblecases]),
              meanmountainsLOC )
zbaseLOC <- c(rep(log(mediannatpopLOC),8),
           rep(log(meanavgregpop),8)
           )

xscenLOC <- rbind(xbaseLOC,xbaseLOC,xbaseLOC,xbaseLOC,xbaseLOC,
               xbaseLOC,xbaseLOC,xbaseLOC)
zscenLOC <- array(zbaseLOC,dim=c(8,1,2))

xscenLOC[1,4] <- 1;   xscenLOC[1,5:8] <- xbase0LOC[5:8];
xscenLOC[2,3] <- 1;   xscenLOC[2,5:8] <- xbase0LOC[5:8];
xscenLOC[3,2] <- 1;   xscenLOC[3,5:8] <- xbase0LOC[5:8];
xscenLOC[4,1] <- 1;   xscenLOC[4,5:8] <- xbase0LOC[5:8];
xscenLOC[5,8] <- 1;   xscenLOC[5,1:4] <- xbase0LOC[1:4];
xscenLOC[6,6] <- 1;   xscenLOC[6,1:4] <- xbase0LOC[1:4];
xscenLOC[7,7] <- 1;   xscenLOC[7,1:4] <- xbase0LOC[1:4];
xscenLOC[8,5] <- 1;   xscenLOC[8,1:4] <- xbase0LOC[1:4];

source("predict.remnlccspec.r")
if (prediction) {
  ctrfct0aLOC <- predict.remnlccspec(model1,
                                     newxdata = xscenLOC[1:4,],
                                     newzdata = zscenLOC[1:4,,,drop=FALSE],
                                     ranefs = "drawn",
                                     level = 0.95,
                                     savememory = 20,
                                     sims = 1000,
                                     selected = zeros,
                                     equation = 1
                                  )
  save(ctrfct0aLOC, file="ctrfct0aLOC.Rdata")
} else {
  load("ctrfct0aLOC.Rdata")
}

if (prediction) {
  ctrfct0bLOC <- predict.remnlccspec(model1,
                                     newxdata = xscenLOC[5:8,],
                                     newzdata = zscenLOC[5:8,,,drop=FALSE],
                                     ranefs = "drawn",
                                     level = 0.95,
                                     savememory = 20,
                                     sims = 1000,
                                     selected = zeros,
                                     equation = 1
                                  )
  save(ctrfct0bLOC, file="ctrfct0bLOC.Rdata")
} else {
  load("ctrfct0bLOC.Rdata")
}



col <- brewer.pal(3,"Dark2")
pch <- matrix(c(17,1,15,
                17,1,15,
                17,16,15,
                17,16,15), nrow=4,ncol=3,byrow=TRUE)


trace1b3 <- ropeladder(x=ctrfct0b$probs[,1],
                       lower=ctrfct0b$probslower[,1],
                       upper=ctrfct0b$probsupper[,1],
                       #labels=scenariosb,
                       col=col[1],
                       pch=pch[,1],
                       lwd=0.5,
                       plot=2,
                       entryheight=0.43,
                       subentryheight=0.85,
                       sublabels = "state",
                       sublabelsyoffset = 0.025                     
                       )

trace2b3 <- ropeladder(x=ctrfct0b$probs[,2],
                       lower=ctrfct0b$probslower[,2],
                       upper=ctrfct0b$probsupper[,2],
                       #labels=scenariosb,
                       col=col[2],
                       pch=pch[,2],
                       lwd=0.5,
                       plot=2,
                       entryheight=0.43,
                       subentryheight=0.85,
                       sublabels = "region",
                       sublabelsyoffset = 0.025                     
                       )

trace3b3 <- ropeladder(x=ctrfct0b$probs[,3],
                       lower=ctrfct0b$probslower[,3],
                       upper=ctrfct0b$probsupper[,3],
                       #labels=scenariosb,
                       col=col[3],
                       pch=pch[,3],
                       lwd=0.5,
                       plot=2,
                       entryheight=0.43,
                       subentryheight=0.85,
                       sublabels = "local",
                       sublabelsyoffset = 0.025                     
                       )

pch <- matrix(c(17,16,15,
                2,1,0,
                2,1,0,
                17,16,15), nrow=4,ncol=3,byrow=TRUE)

trace1bL <- ropeladder(x=ctrfct0bLOC$probs,
                       lower=ctrfct0bLOC$probslower,
                       upper=ctrfct0bLOC$probsupper,
                       labels=scenariosb,
                       col=col[1],
                       pch=pch[,1],
                       lwd=0.5,
                       plot=1,
                       entryheight=0.43,
                       subentryheight=0.85,
                       sublabels = "state",
                       sublabelsyoffset = 0.025                     
                       )

trace3bL <- ropeladder(x=1-ctrfct0bLOC$probs,
                       lower=1-ctrfct0bLOC$probslower,
                       upper=1-ctrfct0bLOC$probsupper,
                       #labels=scenariosb,
                       col=col[3],
                       pch=pch[,3],
                       lwd=0.5,
                       plot=1,
                       entryheight=0.43,
                       subentryheight=0.85,
                       sublabels = "local",
                       sublabelsyoffset = 0.025                     
                       )

tile(trace1b3, trace2b3, trace3b3,
     trace1bL, trace3bL,
     plottitle=list(labels=c("Two-tier countries", "Three-tier countries")),
     topaxis=list(at=c(0,20,40,60,80,100)/100,add=TRUE),
     topaxistitle=list(labels="Probability of allocation"),
     xaxis=list(at=c(0,20,40,60,80,100)/100),
     xaxistitle=list(labels="Probability of allocation"),
     limits=c(0,1),
     width=list(null=2.5, spacer = 3), 
     height=list(xaxistitle=2.5,topaxistitle=2.5,plottitle=2),
     gridlines=list(type="xt"),
     output = list(file="aahp2noreg_allocation0bCMB",type="pdf")
     )




pch <- matrix(c(2,1,0,
                17,1,15,
                17,1,15,
                17,16,15), nrow=4,ncol=3,byrow=TRUE)



trace1a3 <- ropeladder(x=ctrfct0a$probs[,1],
                       lower=ctrfct0a$probslower[,1],
                       upper=ctrfct0a$probsupper[,1],
                       #labels=scenariosa,
                       col=col[1],
                       pch=pch[,1],
                       lwd=0.5,
                       plot=2,
                       entryheight=0.43,
                       subentryheight=0.85,
                       sublabels = "state",
                       sublabelsyoffset = 0.025                     
                       )

trace2a3 <- ropeladder(x=ctrfct0a$probs[,2],
                       lower=ctrfct0a$probslower[,2],
                       upper=ctrfct0a$probsupper[,2],
                       #labels=scenariosa,
                       col=col[2],
                       pch=pch[,2],
                       lwd=0.5,
                       plot=2,
                       entryheight=0.43,
                       subentryheight=0.85,
                       sublabels = "region",
                       sublabelsyoffset = 0.025                     
                       )

trace3a3 <- ropeladder(x=ctrfct0a$probs[,3],
                       lower=ctrfct0a$probslower[,3],
                       upper=ctrfct0a$probsupper[,3],
                       #labels=scenariosa,
                       col=col[3],
                       pch=pch[,3],
                       lwd=0.5,
                       plot=2,
                       entryheight=0.43,
                       subentryheight=0.85,
                       sublabels = "local",
                       sublabelsyoffset = 0.025                     
                       )

pch <- matrix(c(2,1,0,
                2,1,0,
                2,1,0,
                17,16,15), nrow=4,ncol=3,byrow=TRUE)



trace1aL <- ropeladder(x=ctrfct0aLOC$probs,
                       lower=ctrfct0aLOC$probslower,
                       upper=ctrfct0aLOC$probsupper,
                       labels=scenariosa,
                       col=col[1],
                       pch=pch[,1],
                       lwd=0.5,
                       plot=1,
                       entryheight=0.43,
                       subentryheight=0.85,
                       sublabels = "state",
                       sublabelsyoffset = 0.025                     
                       )

trace3aL <- ropeladder(x=1-ctrfct0aLOC$probs,
                       lower=1-ctrfct0aLOC$probslower,
                       upper=1-ctrfct0aLOC$probsupper,
                       #labels=scenariosa,
                       col=col[3],
                       pch=pch[,3],
                       lwd=0.5,
                       plot=1,
                       entryheight=0.43,
                       subentryheight=0.85,
                       sublabels = "local",
                       sublabelsyoffset = 0.025                     
                       )

tile(trace1a3, trace2a3, trace3a3,
     trace1aL, trace3aL,
     plottitle=list(labels=c("Two-tier countries", "Three-tier countries")),
     topaxis=list(at=c(0,20,40,60,80,100)/100,add=TRUE),
     topaxistitle=list(labels="Probability of allocation"),
     xaxis=list(at=c(0,20,40,60,80,100)/100),
     xaxistitle=list(labels="Probability of allocation"),
     limits=c(0,1),
     width=list(null=2.5, spacer = 3), 
     height=list(xaxistitle=2.5,topaxistitle=2.5,plottitle=2),
     gridlines=list(type="xt"),
     output = list(file="aahp2noreg_allocation0aCMB",type="pdf")
     )








# Create counterfactual scenarios:  All combinations, 3 tier
xbase0 <- c(mean(pharma),mean(primac),mean(secter),
            mean(pubhea),mean(leg1),mean(leg2),
            mean(fina),mean(prov),
            mean(post73[possiblecases]),mean(elf85[possiblecases]))
xbase <- c(0,0,0,0,  0,0,0,0, mean(post73[possiblecases]),mean(elf85[possiblecases]),
           meanmountains)
zbase <- c(rep(log(meannatpop),15),
           rep(log(meanavgregpop),15)
           )
xscen3 <- rbind(xbase,xbase,xbase,xbase,xbase,
                xbase,xbase,xbase,xbase,xbase,
                xbase,xbase,xbase,xbase,xbase)
zscen3 <- array(zbase,dim=c(15,1,2))

xscen3[1,1] <- 1;   xscen3[1,5] <- 1
xscen3[2,2] <- 1;   xscen3[2,5] <- 1
xscen3[3,3] <- 1;   xscen3[3,5] <- 1
xscen3[4,4] <- 1;   xscen3[4,5] <- 1

xscen3[5,1] <- 1;   xscen3[5,6] <- 1
xscen3[6,2] <- 1;   xscen3[6,6] <- 1
xscen3[7,3] <- 1;   xscen3[7,6] <- 1
xscen3[8,4] <- 1;   xscen3[8,6] <- 1

xscen3[9,1] <- 1;    xscen3[9,7] <- 1
xscen3[10,2] <- 1;   xscen3[10,7] <- 1
xscen3[11,3] <- 1;   xscen3[11,7] <- 1
xscen3[12,4] <- 1;   xscen3[12,7] <- 1

xscen3[13,2] <- 1;   xscen3[13,8] <- 1
xscen3[14,3] <- 1;   xscen3[14,8] <- 1
xscen3[15,4] <- 1;   xscen3[15,8] <- 1


ctrfct3 <- predict.remnlccspec(model1,
                               newxdata = xscen3,
                               newzdata = zscen3,
                               ranefs = "drawn",
                               level = 0.95,
                               savememory = 20,
                               sims = 1000,
                               selected = nonzeros
                         )

source("sigdiffmultid.r")
complist <- matrix(c(2,3,
                     4,5,
                     6,7,
                     8,9), nrow=4,ncol=2,byrow=TRUE)
diff <- rep(NA,4)
for (i in 1:nrow(complist)) 
    diff[i] <- sigdiffmultid(ctrfct5$simpi[,complist[i,1],,drop=FALSE],ctrfct5$simpi[,complist[i,2],,drop=FALSE])
print(diff)


# Create counterfactual scenarios:  All combinations, All countries
xbase0ALL <- c(mean(pharma),mean(primac),mean(secter),
            mean(pubhea),mean(leg1),mean(leg2),
            mean(fina),mean(prov),
            mean(post73),mean(elf85))
xbaseALL <- c(0,0,0,0,  0,0,0,0, mean(post73),mean(elf85) )
zbaseALL <- c(rep(log(meannatpopALL),15),
           rep(log(meanavgregpopALL),15)
           )
xscen3ALL <- rbind(xbaseALL,xbaseALL,xbaseALL,xbaseALL,xbaseALL,
                xbaseALL,xbaseALL,xbaseALL,xbaseALL,xbaseALL,
                xbaseALL,xbaseALL,xbaseALL,xbaseALL,xbaseALL)
zscen3ALL <- array(zbaseALL,dim=c(16,1,2))

xscen3ALL[1,1] <- 1;   xscen3ALL[1,5] <- 1
xscen3ALL[2,2] <- 1;   xscen3ALL[2,5] <- 1
xscen3ALL[3,3] <- 1;   xscen3ALL[3,5] <- 1
xscen3ALL[4,4] <- 1;   xscen3ALL[4,5] <- 1

xscen3ALL[5,1] <- 1;   xscen3ALL[5,6] <- 1
xscen3ALL[6,2] <- 1;   xscen3ALL[6,6] <- 1
xscen3ALL[7,3] <- 1;   xscen3ALL[7,6] <- 1
xscen3ALL[8,4] <- 1;   xscen3ALL[8,6] <- 1

xscen3ALL[9,1] <- 1;    xscen3ALL[9,7] <- 1
xscen3ALL[10,2] <- 1;   xscen3ALL[10,7] <- 1
xscen3ALL[11,3] <- 1;   xscen3ALL[11,7] <- 1
xscen3ALL[12,4] <- 1;   xscen3ALL[12,7] <- 1

xscen3ALL[13,2] <- 1;   xscen3ALL[13,8] <- 1
xscen3ALL[14,3] <- 1;   xscen3ALL[14,8] <- 1
xscen3ALL[15,4] <- 1;   xscen3ALL[15,8] <- 1


ctrfct3ALL <- predict.remnlccspec(model1,
                         newxdata = xscen3ALL,
                         newzdata = zscen3ALL,
                         ranefs = "drawn",
                         level = 0.95,
                         savememory = 20,
                         sims = 1000
                         )



# Create counterfactual scenarios:  All combinations, 2 tier
xbase0LOC <- c(mean(pharma),mean(primac),mean(secter),
            mean(pubhea),mean(leg1),mean(leg2),
            mean(fina),mean(prov),
            mean(post73[!possiblecases]),mean(elf85[!possiblecases]))
xbaseLOC <- c(0,0,0,0,  0,0,0,0, mean(post73[!possiblecases]),mean(elf85[!possiblecases]),
              meanmountainsLOC)
zbaseLOC <- c(rep(log(mediannatpopLOC),15),
           rep(log(meanavgregpop),15)
           )
xscen3LOC <- rbind(xbaseLOC,xbaseLOC,xbaseLOC,xbaseLOC,xbaseLOC,
                   xbaseLOC,xbaseLOC,xbaseLOC,xbaseLOC,xbaseLOC,
                   xbaseLOC,xbaseLOC,xbaseLOC,xbaseLOC,xbaseLOC
                   )
zscen3LOC <- array(zbaseLOC,dim=c(15,1,2))

xscen3LOC[1,1] <- 1;   xscen3LOC[1,5] <- 1
xscen3LOC[2,2] <- 1;   xscen3LOC[2,5] <- 1
xscen3LOC[3,3] <- 1;   xscen3LOC[3,5] <- 1
xscen3LOC[4,4] <- 1;   xscen3LOC[4,5] <- 1

xscen3LOC[5,1] <- 1;   xscen3LOC[5,6] <- 1
xscen3LOC[6,2] <- 1;   xscen3LOC[6,6] <- 1
xscen3LOC[7,3] <- 1;   xscen3LOC[7,6] <- 1
xscen3LOC[8,4] <- 1;   xscen3LOC[8,6] <- 1

xscen3LOC[9,1] <- 1;    xscen3LOC[9,7] <- 1
xscen3LOC[10,2] <- 1;   xscen3LOC[10,7] <- 1
xscen3LOC[11,3] <- 1;   xscen3LOC[11,7] <- 1
xscen3LOC[12,4] <- 1;   xscen3LOC[12,7] <- 1

xscen3LOC[13,2] <- 1;   xscen3LOC[13,8] <- 1
xscen3LOC[14,3] <- 1;   xscen3LOC[14,8] <- 1
xscen3LOC[15,4] <- 1;   xscen3LOC[15,8] <- 1


ctrfct3LOC <- predict.remnlccspec(model1,
                                  newxdata = xscen3LOC,
                                  newzdata = zscen3LOC,
                                  ranefs = "drawn",
                                  level = 0.95,
                                  savememory = 20,
                                  sims = 1000,
                                  selected = zeros,
                                  equation = 1
                                  )






pch <- c(1,2,3,4,5)
col <- c("blue","red","green","brown")

pch <- c(1,1,1,1,
         2,2,2,2,
         3,3,3,3,
         4,4,4
         )
col <- c("blue","red","green","violet",
         "blue","red","green","violet",
         "blue","red","green","violet",
         "blue","red","green","violet"
         )

col <- c("red","red","red","red",
         "darkviolet","darkviolet","darkviolet","darkviolet",
         "darkgreen","darkgreen","darkgreen","darkgreen",
         "blue","blue","blue"
         )



pdf("ternary1noreg.pdf",width=5,height=5,fonts="sans")
source("ternaryplot2.R")
ternaryplot2(ctrfct3$probs,
            pch=c(15,2,1,5),
            col=col,
             cex=0.5,
            dimnames=c("State","Region","Local"),
             axislabels="outside",
             axislabels_color = "black",
             grid = "solid"
            )

grid.points(x=-0.05,y=0.8,pch=5,default.units="npc",gp=gpar(cex=0.7))
grid.points(x=-0.05,y=0.75,pch=2,default.units="npc",gp=gpar(cex=0.7))
grid.points(x=-0.05,y=0.7,pch=1,default.units="npc",gp=gpar(cex=0.7))
grid.points(x=-0.05,y=0.65,pch=15,default.units="npc",gp=gpar(cex=0.7))

grid.text(label="Public Health",x=-0.02,y=0.8,gp=gpar(cex=0.8),just="left")
grid.text(label="Primary Care",x=-0.02,y=0.75,gp=gpar(cex=0.8),just="left")
grid.text(label="Secondary/Tertiary",x=-0.02,y=0.7,gp=gpar(cex=0.8),just="left")
grid.text(label="Pharmacueticals",x=-0.02,y=0.65,gp=gpar(cex=0.8),just="left")

dev.off()



pdf("ternary1noregALL.pdf",width=5,height=5,fonts="sans")
source("ternaryplot2.R")
ternaryplot2(ctrfct3ALL$probs,
            pch=c(15,2,8,5),
            col=col,
             cex=0.5,
            dimnames=c("State","Region","Local"),
             axislabels="outside",
             axislabels_color = "black",
             grid = "solid"
            )

grid.points(x=0.05,y=0.8,pch=5,default.units="npc",gp=gpar(cex=0.7))
grid.points(x=0.05,y=0.75,pch=2,default.units="npc",gp=gpar(cex=0.7))
grid.points(x=0.05,y=0.7,pch=8,default.units="npc",gp=gpar(cex=0.7))
grid.points(x=0.05,y=0.65,pch=15,default.units="npc",gp=gpar(cex=0.7))

grid.text(label="Public Health",x=0.08,y=0.8,gp=gpar(cex=0.8),just="left")
grid.text(label="Primary Care",x=0.08,y=0.75,gp=gpar(cex=0.8),just="left")
grid.text(label="Secondary/Tertiary",x=0.08,y=0.7,gp=gpar(cex=0.8),just="left")
grid.text(label="Pharmacueticals",x=0.08,y=0.65,gp=gpar(cex=0.8),just="left")

dev.off()



# 2 tier

statevslocal1a <- ctrfct3LOC$probs
statevslocal2a <- 1-ctrfct3LOC$probs
statevslocala <- cbind(statevslocal1a,rep(0,15),statevslocal2a)


pdf("ternary1noregLOC.pdf",width=5,height=5,fonts="sans")
source("ternaryplot2.R")
ternaryplot2(statevslocala,
            pch=c(15,2,1,5),
            col=col,
             cex=0.5,
            dimnames=c("State","Region","Local"),
             axislabels="outside",
             axislabels_color = "black",
             grid = "solid"
            )

grid.points(x=-0.05,y=0.8,pch=5,default.units="npc",gp=gpar(cex=0.7))
grid.points(x=-0.05,y=0.75,pch=2,default.units="npc",gp=gpar(cex=0.7))
grid.points(x=-0.05,y=0.7,pch=1,default.units="npc",gp=gpar(cex=0.7))
grid.points(x=-0.05,y=0.65,pch=15,default.units="npc",gp=gpar(cex=0.7))

grid.text(label="Public Health",x=-0.02,y=0.8,gp=gpar(cex=0.8),just="left")
grid.text(label="Primary Care",x=-0.02,y=0.75,gp=gpar(cex=0.8),just="left")
grid.text(label="Secondary/Tertiary",x=-0.02,y=0.7,gp=gpar(cex=0.8),just="left")
grid.text(label="Pharmacueticals",x=-0.02,y=0.65,gp=gpar(cex=0.8),just="left")

dev.off()





# Create counterfactual scenarios:  Baseline
xbase <- c(mean(pharma),mean(primac),mean(secter),
            mean(pubhea),mean(leg1),mean(leg2),
            mean(fina),mean(prov),
           mean(post73[possiblecases]),mean(elf85[possiblecases]))
zbase <- c(rep(log(meannatpop),1),
           rep(log(meanavgregpop),1)
           )
xscen0 <- rbind(xbase
                )
zscen0 <- array(zbase,dim=c(1,1,2))

ctrfct0 <- predict.remnlccspec(model1,
                         newxdata = xscen0,
                         newzdata = zscen0,
                         ranefs = "drawn",
                         level = 0.95,
                         savememory = FALSE,
                         sims = 1000,
                         selected = nonzeros
                         )


# Create counterfactual scenarios:  Baseline
xbaseALL <- c(mean(pharma),mean(primac),mean(secter),
            mean(pubhea),mean(leg1),mean(leg2),
            mean(fina),mean(prov),
           mean(post73),mean(elf85))
zbaseALL <- c(rep(log(meannatpopALL),1),
           rep(log(meanavgregpopALL),1)
           )
xscen0ALL <- rbind(xbaseALL
                )
zscen0ALL <- array(zbase,dim=c(1,1,2))

ctrfct0ALL <- predict.remnlccspec(model1,
                         newxdata = xscen0ALL,
                         newzdata = zscen0ALL,
                         ranefs = "drawn",
                         level = 0.95,
                         savememory = FALSE,
                         sims = 1000
                         )


#0.573863636
#0.352272727
#0.073863636


ternary2(ctrfct0ALL$probs,
            pch="+",
            col=col,
            dimnames=c("State","Region","Local"),
            axislabels="outside"
            )



# Create  counterfactual scenarios:  Other covariates, Three tier
xbase <- c(mean(pharma),mean(primac),mean(secter),
           mean(pubhea),mean(leg1),mean(leg2),
           mean(fina),mean(prov),
           mean(post73[possiblecases]),mean(elf85[possiblecases]),
           meanmountains)
zbase <- c(rep(log(meannatpop),13),
           rep(log(meanavgregpop),13)
           )
xscen5 <- rbind(xbase,xbase,xbase,xbase,xbase,
                xbase,xbase,xbase,xbase,xbase,
                xbase,xbase,xbase)
zscen5 <- array(zbase,dim=c(13,1,2))

xscen5[2,9] <- 1
xscen5[3,9] <- 0

xscen5[4,10] <- quantile(elf85[possiblecases],probs=0.25)#mean(elf85[possiblecases]) + sd(elf85[possiblecases])
xscen5[5,10] <- quantile(elf85[possiblecases],probs=0.75)#mean(elf85[possiblecases]) - sd(elf85[possiblecases])

# Low national pop, medium number of regions
zscen5[6,1,1] <- log(lownatpop)
zscen5[6,1,2] <- log(lownatpop/meannunreg)

# High national pop, medium number of regions
zscen5[7,1,1] <- log(upnatpop)
zscen5[7,1,2] <- log(upnatpop/meannunreg)

# Medium nat pop, many regions (small regions)
zscen5[8,1,2] <- log(meannatpop/upnunreg)

# Medium nat pop, few regions (large regions)
zscen5[9,1,2] <- log(meannatpop/lownunreg)

# Low nat pop, few regions
zscen5[10,1,1] <- log(lownatpop)
zscen5[10,1,2] <- log(lownatpop/lownunreg)

# High nat pop, many regions
zscen5[11,1,1] <- log(upnatpop)
zscen5[11,1,2] <- log(upnatpop/upnunreg)

# Few mountains
xscen5[12,11] <- lowmountains

# Many mountains
xscen5[13,11] <- upmountains



source("predict.remnlccspec.r")
ctrfct5 <- predict.remnlccspec(model1,
                         newxdata = xscen5,
                         newzdata = zscen5,
                         ranefs = "drawn",
                         level = 0.95,
                         savememory = 20,
                         sims = 1000,
                         selected = nonzeros
                         )



source("sigdiffmultid.r")
complist <- matrix(c(2,3,
                     4,5,
                     6,7,
                     8,9,
                     10,11,
                     12,13), nrow=6,ncol=2,byrow=TRUE)
diff <- rep(NA,4)
for (i in 1:nrow(complist)) 
    diff[i] <- sigdiffmultid(ctrfct5$simpi[,complist[i,1],,drop=FALSE],ctrfct5$simpi[,complist[i,2],,drop=FALSE])
print(diff)






# Create  counterfactual scenarios:  Other covariates, Two tier
xbaseLOC <- c(mean(pharma),mean(primac),mean(secter),
              mean(pubhea),mean(leg1),mean(leg2),
              mean(fina),mean(prov),
              mean(post73[!possiblecases]),mean(elf85[!possiblecases]),
              meanmountainsLOC)
zbaseLOC <- c(rep(log(mediannatpopLOC),7),
              rep(log(meanavgregpop),7)
              )
xscen5LOC <- rbind(xbaseLOC,xbaseLOC,xbaseLOC,xbaseLOC,xbaseLOC,
                   xbaseLOC,xbaseLOC
                   )
zscen5LOC <- array(zbaseLOC,dim=c(7,1,2))


xscen5LOC[2,10] <- quantile(elf85[!possiblecases],probs=0.25)#mean(elf85[!possiblecases]) + sd(elf85[!possiblecases])
xscen5LOC[3,10] <- quantile(elf85[!possiblecases],probs=0.75)#mean(elf85[!possiblecases]) - sd(elf85[!possiblecases])

# Low national pop, medium number of regions
zscen5LOC[4,1,1] <- log(lownatpopLOC)

# High national pop, medium number of regions
zscen5LOC[5,1,1] <- log(upnatpopLOC)

# Few mountains
xscen5LOC[6,11] <- lowmountainsLOC

# Many mountains
xscen5LOC[7,11] <- upmountainsLOC


source("predict.remnlccspec.r")
ctrfct5LOC <- predict.remnlccspec(model1,
                                  newxdata = xscen5LOC,
                                  newzdata = zscen5LOC,
                                  ranefs = "drawn",
                                  level = 0.95,
                                  savememory = 20,
                                  sims = 1000,
                                  selected = zeros,
                                  equation = 1
                                  )





# Create  counterfactual scenarios:  Other covariates, all countries
xbaseALL <- c(mean(pharma),mean(primac),mean(secter),
            mean(pubhea),mean(leg1),mean(leg2),
            mean(fina),mean(prov),
           mean(post73),mean(elf85))
zbaseALL <- c(rep(log(meannatpopALL),9),
           rep(log(meanavgregpopALL),9)
           )
xscen5ALL <- rbind(xbaseALL,xbaseALL,xbaseALL,xbaseALL,xbaseALL,
                xbaseALL,xbaseALL,xbaseALL,xbaseALL)
zscen5ALL <- array(zbaseALL,dim=c(9,1,2))

xscen5ALL[2,9] <- 1
xscen5ALL[3,9] <- 0

xscen5ALL[4,10] <- mean(elf85) + sd(elf85)
xscen5ALL[5,10] <- mean(elf85) - sd(elf85)

zscen5ALL[6,1,1] <- log(upnatpopALL)

zscen5ALL[7,1,1] <- log(lownatpopALL)

zscen5ALL[8,1,2] <- log(lowavgregpopALL)
zscen5ALL[9,1,2] <- log(upavgregpopALL)


source("predict.remnlccspec.r")
ctrfct5ALL <- predict.remnlccspec(model1,
                         newxdata = xscen5ALL,
                         newzdata = zscen5ALL,
                         ranefs = "drawn",
                         level = 0.95,
                         savememory = 20,
                         sims = 1000#,
                         #selected = nonzeros
                         )





pdf("ternaryothercov3noreg.pdf",width=5,height=5,fonts="sans")
source("ternaryplot2.R")
ternaryplot2(ctrfct5$probs,
             pch=c(3,15,15,21,21,17,17,5,5,3,3,25,25),
             #labels=c("*","n","o","e+","e-","p+","p-","r+","r-"),
             col=c("black","blue","blue","darkviolet","darkviolet","darkgreen","darkgreen","blue","blue","orange","orange","brown","brown"),
             #col="black",
             cex=0.5,
            #id=crossscen,
            dimnames=c("State","Region","Local"),
             axislabels="outside",
             axislabels_color = "black",
             grid = "solid"
            )
dev.off()



statevslocal1b <- ctrfct5LOC$probs
statevslocal2b <- 1-ctrfct5LOC$probs
statevslocalb <- cbind(statevslocal1b,rep(0,7),statevslocal2b)


pdf("ternaryothercov3noregLOC.pdf",width=5,height=5,fonts="sans")
source("ternaryplot2.R")
ternaryplot2(statevslocalb,
             pch=c(3,21,21,17,17,25,25),
             #labels=c("*","n","o","e+","e-","p+","p-","r+","r-"),
             col=c("black","darkviolet","darkviolet","darkgreen","darkgreen","brown","brown"),
             #col="black",
             cex=0.5,
            #id=crossscen,
            dimnames=c("State","Region","Local"),
             axislabels="outside",
             axislabels_color = "black",
             grid = "solid"
            )
dev.off()






pdf("ternaryothercovnoregALL.pdf",width=5,height=5,fonts="sans")
source("ternaryplot2.R")
ternaryplot2(ctrfct5ALL$probs,
               labels=c("*","n","o","e+","e-","p+","p-","r+","r-"),
            col="black",
             cex=0.5,
            #id=crossscen,
            dimnames=c("State","Region","Local"),
             axislabels="outside",
             axislabels_color = "black",
             grid = "solid"
            )

dev.off()




# Create counterfactual scenarios:  All random effects, three tiers
xbase <- c(mean(pharma),mean(primac),mean(secter),
            mean(pubhea),mean(leg1),mean(leg2),
            mean(fina),mean(prov),
           mean(post73[possiblecases]),mean(elf85[possiblecases]),
           meanmountains)
zbase <- c(rep(log(meannatpop),28),
           rep(log(meanavgregpop),28)
           )
xscen4 <- rbind(xbase,xbase,xbase,xbase,xbase,
                xbase,xbase,xbase,xbase,xbase,
                xbase,xbase,xbase,xbase,xbase,
                xbase,xbase,xbase,xbase,xbase,
                xbase,xbase,xbase,xbase,xbase,
                xbase,xbase,xbase
                )
zscen4 <- array(zbase,dim=c(28,1,2))



ctrfct4 <- predict.remnlccspec(model1,
                         newxdata = xscen4,
                         newzdata = zscen4,
                         ranefs = "observed",
                         level = 0.95,
                         savememory = 20,
                         sims = 1000,
                         selected = nonzeros
                         )



# Create counterfactual scenarios:  All random effects, two tiers
xbaseLOC <- c(mean(pharma),mean(primac),mean(secter),
            mean(pubhea),mean(leg1),mean(leg2),
            mean(fina),mean(prov),
           mean(post73[!possiblecases]),mean(elf85[!possiblecases]),
              meanmountainsLOC)
zbaseLOC <- c(rep(log(mediannatpopLOC),28),
           rep(log(meanavgregpop),28)
           )
xscen4LOC <- rbind(xbaseLOC,xbaseLOC,xbaseLOC,xbaseLOC,xbaseLOC,
                   xbaseLOC,xbaseLOC,xbaseLOC,xbaseLOC,xbaseLOC,
                   xbaseLOC,xbaseLOC,xbaseLOC,xbaseLOC,xbaseLOC,
                   xbaseLOC,xbaseLOC,xbaseLOC,xbaseLOC,xbaseLOC,
                   xbaseLOC,xbaseLOC,xbaseLOC,xbaseLOC,xbaseLOC,
                   xbaseLOC,xbaseLOC,xbaseLOC
                   )
                
zscen4LOC <- array(zbaseLOC,dim=c(28,1,2))



ctrfct4LOC <- predict.remnlccspec(model1,
                                  newxdata = xscen4LOC,
                                  newzdata = zscen4LOC,
                                  ranefs = "observed",
                                  level = 0.95,
                                  savememory = 20,
                                  sims = 1000,
                                  selected = zeros,
                                  equation=1
                                  )





# Create counterfactual scenarios:  All random effects
xbaseALL <- c(mean(pharma),mean(primac),mean(secter),
            mean(pubhea),mean(leg1),mean(leg2),
            mean(fina),mean(prov),
           mean(post73),mean(elf85))
zbaseALL <- c(rep(log(avgnatpopALL),28),
           rep(log(meanavgregpopALL),28)
           )
xscen4ALL <- rbind(xbaseALL,xbaseALL,xbaseALL,xbaseALL,xbaseALL,
                xbaseALL,xbaseALL,xbaseALL,xbaseALL,xbaseALL,
                xbaseALL,xbaseALL,xbaseALL,xbaseALL,xbaseALL,
                xbaseALL,xbaseALL,xbaseALL,xbaseALL,xbaseALL,
                xbaseALL,xbaseALL,xbaseALL,xbaseALL,xbaseALL,
                xbaseALL,xbaseALL,xbaseALL
                )
zscen4ALL <- array(zbaseALL,dim=c(28,1,2))



ctrfct4ALL <- predict.remnlccspec(model1,
                         newxdata = xscen4ALL,
                         newzdata = zscen4ALL,
                         ranefs = "observed",
                         level = 0.95,
                         savememory = 20,
                         sims = 1000#,
                         #selected = nonzeros
                         )


pch <- c(1)
col <- c("black")

#Austria   Belgium   Czech_rep Denmark   Germany   Hungary   Italy    
#Spain     Sweden    Swiss     UK     

ctyabbr <- c("Aus","Bel","Cze","Den","Ger","Hun","Ita","Spa","Swe","Swi","UK")

ctyabbr <- c("Austria",     "Belgium",     "Bulgaria",    "Denmark",     "France",      "Germany",     "Italy",      
             "Netherlands", "Poland",      "Romania",     "Slovakia",    "Spain",       "Sweden",      "Swiss",      "UK")  


pdf("ternaryrandomeffects2noreg.pdf",width=5,height=5,fonts="sans")
source("ternaryplot2.R")
ternaryplot2(ctrfct4$probs[nonzeros,],
            labels=ctyabbr,
             #pch=16,
            col="red",
             cex=0.5,
            #id=crossscen,
            dimnames=c("State","Region","Local"),
             axislabels="outside",
             axislabels_color = "black",
             grid = "solid"
            )
dev.off()

    

pdf("ternaryrandomeffectsALLnoreg.pdf",width=5,height=5,fonts="sans")
source("ternaryplot2.R")
ternaryplot2(ctrfct4ALL$probs[nonzeros,],
            labels=ctyabbr,
            col=col,
             cex=0.5,
            #id=crossscen,
            dimnames=c("State","Region","Local"),
             axislabels="outside",
             axislabels_color = "black",
             grid = "solid"
            )
dev.off()



statevslocal1 <- ctrfct4LOC$probs
statevslocal2 <- 1-ctrfct4LOC$probs
statevslocal <- cbind(statevslocal1,rep(0,28),statevslocal2)

ctynames <- NULL
for (i in 1:28) {
  ctynames <- c(ctynames, unique(as.character(data$country)[data$ctynum==i]))
}
ctyzeros <- ctynames[zeros]


pdf("ternaryrandomeffects2noregNONFEDlabels.pdf",width=5,height=5,fonts="sans")
source("ternaryplot2.R")
ternaryplot2(statevslocal[zeros,],
            labels=ctyzeros,
             #pch=16,
             col="black",
             cex=0.5,
            #id=crossscen,
             dimnames=c("State","Region","Local"),
             axislabels="outside",
             axislabels_color = "black",
             grid = "solid"
            )
dev.off()


pdf("ternaryrandomeffects2noregNONFED.pdf",width=5,height=5,fonts="sans")
source("ternaryplot2.R")
ternaryplot2(statevslocal[zeros,],
            #labels=ctyzeros,
             #pch=16,
             col="black",
             cex=0.5,
            #id=crossscen,
             dimnames=c("State","Region","Local"),
             axislabels="outside",
             axislabels_color = "black",
             grid = "solid"
            )
dev.off()

